==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/costmanagement/kotlin/inputs/ReportFilterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.costmanagement.kotlin.inputs

import com.pulumi.azurenative.costmanagement.inputs.ReportFilterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The filter expression to be used in the report.
 * @property and The logical "AND" expression. Must have at least 2 items.
 * @property dimension Has comparison expression for a dimension
 * @property not The logical "NOT" expression.
 * @property or The logical "OR" expression. Must have at least 2 items.
 * @property tag Has comparison expression for a tag
 */
public data class ReportFilterArgs(
    public val and: Output<List<ReportFilterArgs>>? = null,
    public val dimension: Output<ReportComparisonExpressionArgs>? = null,
    public val not: Output<ReportFilterArgs>? = null,
    public val or: Output<List<ReportFilterArgs>>? = null,
    public val tag: Output<ReportComparisonExpressionArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.costmanagement.inputs.ReportFilterArgs> {
    override fun toJava(): com.pulumi.azurenative.costmanagement.inputs.ReportFilterArgs =
        com.pulumi.azurenative.costmanagement.inputs.ReportFilterArgs.builder()
            .and(and?.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .dimension(dimension?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .not(not?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .or(or?.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .tag(tag?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [ReportFilterArgs].
 */
@PulumiTagMarker
public class ReportFilterArgsBuilder internal constructor() {
    private var and: Output<List<ReportFilterArgs>>? = null

    private var dimension: Output<ReportComparisonExpressionArgs>? = null

    private var not: Output<ReportFilterArgs>? = null

    private var or: Output<List<ReportFilterArgs>>? = null

    private var tag: Output<ReportComparisonExpressionArgs>? = null

    /**
     * @param value The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("otiuvbcqdabdfvpp")
    public suspend fun and(`value`: Output<List<ReportFilterArgs>>) {
        this.and = value
    }

    @JvmName("cqiccjkhxisipfji")
    public suspend fun and(vararg values: Output<ReportFilterArgs>) {
        this.and = Output.all(values.asList())
    }

    /**
     * @param values The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("hhhsgwyuekpikarg")
    public suspend fun and(values: List<Output<ReportFilterArgs>>) {
        this.and = Output.all(values)
    }

    /**
     * @param value Has comparison expression for a dimension
     */
    @JvmName("mggroiynkjlclhpb")
    public suspend fun dimension(`value`: Output<ReportComparisonExpressionArgs>) {
        this.dimension = value
    }

    /**
     * @param value The logical "NOT" expression.
     */
    @JvmName("tqhgejnypxivgikh")
    public suspend fun not(`value`: Output<ReportFilterArgs>) {
        this.not = value
    }

    /**
     * @param value The logical "OR" expression. Must have at least 2 items.
     */
    @JvmName("hfjvrvikcbhhhkni")
    public suspend fun or(`value`: Output<List<ReportFilterArgs>>) {
        this.or = value
    }

    @JvmName("grmuhpcytcyxmuvj")
    public suspend fun or(vararg values: Output<ReportFilterArgs>) {
        this.or = Output.all(values.asList())
    }

    /**
     * @param values The logical "OR" expression. Must have at least 2 items.
     */
    @JvmName("pbaqcmcrsfdnitqs")
    public suspend fun or(values: List<Output<ReportFilterArgs>>) {
        this.or = Output.all(values)
    }

    /**
     * @param value Has comparison expression for a tag
     */
    @JvmName("hhwdnurwfregxooo")
    public suspend fun tag(`value`: Output<ReportComparisonExpressionArgs>) {
        this.tag = value
    }

    /**
     * @param value The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("lfrirnlngfjdfwce")
    public suspend fun and(`value`: List<ReportFilterArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.and = mapped
    }

    /**
     * @param argument The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("hpdnegkdgnsgyuka")
    public suspend fun and(argument: List<suspend ReportFilterArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ReportFilterArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.and = mapped
    }

    /**
     * @param argument The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("jlxbdabedsqgaomk")
    public suspend fun and(vararg argument: suspend ReportFilterArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            ReportFilterArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.and = mapped
    }

    /**
     * @param argument The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("kjlgyqbarrbihyqc")
    public suspend fun and(argument: suspend ReportFilterArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ReportFilterArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.and = mapped
    }

    /**
     * @param values The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("ollainnlbidlbgqv")
    public suspend fun and(vararg values: ReportFilterArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.and = mapped
    }

    /**
     * @param value Has comparison expression for a dimension
     */
    @JvmName("gsjxifdeckhmqhsb")
    public suspend fun dimension(`value`: ReportComparisonExpressionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dimension = mapped
    }

    /**
     * @param argument Has comparison expression for a dimension
     */
    @JvmName("bmkbgaakmosrcurn")
    public suspend fun dimension(argument: suspend ReportComparisonExpressionArgsBuilder.() -> Unit) {
        val toBeMapped = ReportComparisonExpressionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.dimension = mapped
    }

    /**
     * @param value The logical "NOT" expression.
     */
    @JvmName("tisuwhgdyxvgxjjd")
    public suspend fun not(`value`: ReportFilterArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.not = mapped
    }

    /**
     * @param argument The logical "NOT" expression.
     */
    @JvmName("uhgnqjbpacmnjuhn")
    public suspend fun not(argument: suspend ReportFilterArgsBuilder.() -> Unit) {
        val toBeMapped = ReportFilterArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.not = mapped
    }

    /**
     * @param value The logical "OR" expression. Must have at least 2 items.
     */
    @JvmName("fivejtildqctinie")
    public suspend fun or(`value`: List<ReportFilterArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.or = mapped
    }

    /**
     * @param argument The logical "OR" expression. Must have at least 2 items.
     */
    @JvmName("lsaedvpcvnpubtas")
    public suspend fun or(argument: List<suspend ReportFilterArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ReportFilterArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.or = mapped
    }

    /**
     * @param argument The logical "OR" expression. Must have at least 2 items.
     */
    @JvmName("fabxfbtetxpsisja")
    public suspend fun or(vararg argument: suspend ReportFilterArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            ReportFilterArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.or = mapped
    }

    /**
     * @param argument The logical "OR" expression. Must have at least 2 items.
     */
    @JvmName("ywtujnmxlytqjygb")
    public suspend fun or(argument: suspend ReportFilterArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ReportFilterArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.or = mapped
    }

    /**
     * @param values The logical "OR" expression. Must have at least 2 items.
     */
    @JvmName("tscnmhtpcfnfgrpw")
    public suspend fun or(vararg values: ReportFilterArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.or = mapped
    }

    /**
     * @param value Has comparison expression for a tag
     */
    @JvmName("pfhouhfaacdbyegk")
    public suspend fun tag(`value`: ReportComparisonExpressionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tag = mapped
    }

    /**
     * @param argument Has comparison expression for a tag
     */
    @JvmName("upsywurdoommwpuq")
    public suspend fun tag(argument: suspend ReportComparisonExpressionArgsBuilder.() -> Unit) {
        val toBeMapped = ReportComparisonExpressionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.tag = mapped
    }

    internal fun build(): ReportFilterArgs = ReportFilterArgs(
        and = and,
        dimension = dimension,
        not = not,
        or = or,
        tag = tag,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/costmanagement/kotlin/inputs/ReportFilterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.costmanagement.kotlin.inputs

import com.pulumi.azurenative.costmanagement.inputs.ReportFilterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The filter expression to be used in the report.
 * @property and The logical "AND" expression. Must have at least 2 items.
 * @property dimension Has comparison expression for a dimension
 * @property not The logical "NOT" expression.
 * @property or The logical "OR" expression. Must have at least 2 items.
 * @property tag Has comparison expression for a tag
 */
public data class ReportFilterArgs(
    public val and: Output<List<ReportFilterArgs>>? = null,
    public val dimension: Output<ReportComparisonExpressionArgs>? = null,
    public val not: Output<ReportFilterArgs>? = null,
    public val or: Output<List<ReportFilterArgs>>? = null,
    public val tag: Output<ReportComparisonExpressionArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.costmanagement.inputs.ReportFilterArgs> {
    override fun toJava(): com.pulumi.azurenative.costmanagement.inputs.ReportFilterArgs =
        com.pulumi.azurenative.costmanagement.inputs.ReportFilterArgs.builder()
            .and(and?.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .dimension(dimension?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .not(not?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .or(or?.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .tag(tag?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [ReportFilterArgs].
 */
@PulumiTagMarker
public class ReportFilterArgsBuilder internal constructor() {
    private var and: Output<List<ReportFilterArgs>>? = null

    private var dimension: Output<ReportComparisonExpressionArgs>? = null

    private var not: Output<ReportFilterArgs>? = null

    private var or: Output<List<ReportFilterArgs>>? = null

    private var tag: Output<ReportComparisonExpressionArgs>? = null

    /**
     * @param value The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("xncpmofnkyxhkvej")
    public suspend fun and(`value`: Output<List<ReportFilterArgs>>) {
        this.and = value
    }

    @JvmName("hcurbeuelhrinmcp")
    public suspend fun and(vararg values: Output<ReportFilterArgs>) {
        this.and = Output.all(values.asList())
    }

    /**
     * @param values The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("ymefnvkcbvymiijo")
    public suspend fun and(values: List<Output<ReportFilterArgs>>) {
        this.and = Output.all(values)
    }

    /**
     * @param value Has comparison expression for a dimension
     */
    @JvmName("luvmrelsktpfffur")
    public suspend fun dimension(`value`: Output<ReportComparisonExpressionArgs>) {
        this.dimension = value
    }

    /**
     * @param value The logical "NOT" expression.
     */
    @JvmName("bsfekimxwqfpmxvy")
    public suspend fun not(`value`: Output<ReportFilterArgs>) {
        this.not = value
    }

    /**
     * @param value The logical "OR" expression. Must have at least 2 items.
     */
    @JvmName("rbukgldrjufbcslr")
    public suspend fun or(`value`: Output<List<ReportFilterArgs>>) {
        this.or = value
    }

    @JvmName("awrndnwjocmkhyjv")
    public suspend fun or(vararg values: Output<ReportFilterArgs>) {
        this.or = Output.all(values.asList())
    }

    /**
     * @param values The logical "OR" expression. Must have at least 2 items.
     */
    @JvmName("ritqqftyxfvcigxn")
    public suspend fun or(values: List<Output<ReportFilterArgs>>) {
        this.or = Output.all(values)
    }

    /**
     * @param value Has comparison expression for a tag
     */
    @JvmName("jmbnihurtdlqeiyf")
    public suspend fun tag(`value`: Output<ReportComparisonExpressionArgs>) {
        this.tag = value
    }

    /**
     * @param value The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("tplstsplmdcccdvf")
    public suspend fun and(`value`: List<ReportFilterArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.and = mapped
    }

    /**
     * @param argument The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("obuolikwxktbjlsd")
    public suspend fun and(argument: List<suspend ReportFilterArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ReportFilterArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.and = mapped
    }

    /**
     * @param argument The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("byuefdkacghebabl")
    public suspend fun and(vararg argument: suspend ReportFilterArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            ReportFilterArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.and = mapped
    }

    /**
     * @param argument The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("hylnwglrlupyheej")
    public suspend fun and(argument: suspend ReportFilterArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ReportFilterArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.and = mapped
    }

    /**
     * @param values The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("aevvhswkvcicaiqf")
    public suspend fun and(vararg values: ReportFilterArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.and = mapped
    }

    /**
     * @param value Has comparison expression for a dimension
     */
    @JvmName("jooxweglkuwdgaas")
    public suspend fun dimension(`value`: ReportComparisonExpressionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dimension = mapped
    }

    /**
     * @param argument Has comparison expression for a dimension
     */
    @JvmName("wprrutlvoxsywkes")
    public suspend fun dimension(argument: suspend ReportComparisonExpressionArgsBuilder.() -> Unit) {
        val toBeMapped = ReportComparisonExpressionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.dimension = mapped
    }

    /**
     * @param value The logical "NOT" expression.
     */
    @JvmName("hgefwrbvwwjeibaj")
    public suspend fun not(`value`: ReportFilterArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.not = mapped
    }

    /**
     * @param argument The logical "NOT" expression.
     */
    @JvmName("rpiomkhpnrcduold")
    public suspend fun not(argument: suspend ReportFilterArgsBuilder.() -> Unit) {
        val toBeMapped = ReportFilterArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.not = mapped
    }

    /**
     * @param value The logical "OR" expression. Must have at least 2 items.
     */
    @JvmName("cjsaoeowohvihmpg")
    public suspend fun or(`value`: List<ReportFilterArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.or = mapped
    }

    /**
     * @param argument The logical "OR" expression. Must have at least 2 items.
     */
    @JvmName("wpvchydyvwhpaurj")
    public suspend fun or(argument: List<suspend ReportFilterArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ReportFilterArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.or = mapped
    }

    /**
     * @param argument The logical "OR" expression. Must have at least 2 items.
     */
    @JvmName("ovhlojbfytwmdhlu")
    public suspend fun or(vararg argument: suspend ReportFilterArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            ReportFilterArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.or = mapped
    }

    /**
     * @param argument The logical "OR" expression. Must have at least 2 items.
     */
    @JvmName("dncuegrfuxuuuquo")
    public suspend fun or(argument: suspend ReportFilterArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ReportFilterArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.or = mapped
    }

    /**
     * @param values The logical "OR" expression. Must have at least 2 items.
     */
    @JvmName("safyycyebwpgyvgy")
    public suspend fun or(vararg values: ReportFilterArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.or = mapped
    }

    /**
     * @param value Has comparison expression for a tag
     */
    @JvmName("ifogukldttkcdwva")
    public suspend fun tag(`value`: ReportComparisonExpressionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tag = mapped
    }

    /**
     * @param argument Has comparison expression for a tag
     */
    @JvmName("dorfkcyijejccdqo")
    public suspend fun tag(argument: suspend ReportComparisonExpressionArgsBuilder.() -> Unit) {
        val toBeMapped = ReportComparisonExpressionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.tag = mapped
    }

    internal fun build(): ReportFilterArgs = ReportFilterArgs(
        and = and,
        dimension = dimension,
        not = not,
        or = or,
        tag = tag,
    )
}
